@@ -13,7 +13,7 @@ from PIL import Image
 
 from typing import Optional
 
-def plot_TSNE_with_images(feature_vec: np.array, label_vec: np.array, imgs: np.array, point_class_belonging: list = None, title: Optional[str] = None, reducer_seed: int = 42, marker_size: int = 3):
+def plot_TSNE_with_images(feature_vec: np.array, label_vec: np.array, imgs: np.array, point_class_belonging: list = None, title: Optional[str] = None, reducer_seed: int = 42, marker_size: float = 3, marker_opacity: float = 0.8):
     """
     This function creates an interactive chart (plotly) by reducing the
     features (with TSNE) of "feature_vec" and creating a scatter plot
@@ -41,12 +41,14 @@ def plot_TSNE_with_images(feature_vec: np.array, label_vec: np.array, imgs: np.a
             The seed that is used for the reducing of the feature space.
         marker_size (optional):
             The size of the marker.
+        marker_opacity (optional):
+            The opacity of the marker.
     """
     embedding = TSNE(n_components=2, random_state=reducer_seed, init='pca', learning_rate='auto').fit_transform(feature_vec)
-    _2dplot_scatter_with_images(embedding, label_vec, imgs, point_class_belonging, title, marker_size)
+    _2dplot_scatter_with_images(embedding, label_vec, imgs, point_class_belonging, title, marker_size, marker_opacity)
 
 
-def plot_PCA_with_images(feature_vec: np.array, label_vec: np.array, imgs: np.array, point_class_belonging: list = None, title: Optional[str] = None, reducer_seed: int = 42, marker_size: int = 3):
+def plot_PCA_with_images(feature_vec: np.array, label_vec: np.array, imgs: np.array, point_class_belonging: list = None, title: Optional[str] = None, reducer_seed: int = 42, marker_size: float = 3, marker_opacity: float = 0.8):
     """
     This function creates an interactive chart (plotly) by reducing the
     features (with PCA) of "feature_vec" and creating a scatter plot
@@ -74,12 +76,14 @@ def plot_PCA_with_images(feature_vec: np.array, label_vec: np.array, imgs: np.ar
             The seed that is used for the reducing of the feature space.
         marker_size (optional):
             The size of the marker.
+        marker_opacity (optional):
+            The opacity of the marker.
     """
     embedding = PCA(n_components=2, random_state=reducer_seed).fit_transform(feature_vec)
-    _2dplot_scatter_with_images(embedding, label_vec, imgs, point_class_belonging, title, marker_size)
+    _2dplot_scatter_with_images(embedding, label_vec, imgs, point_class_belonging, title, marker_size, marker_opacity)
 
 
-def _2dplot_scatter_with_images(data: np.array, labels: np.array, imgs: np.array, point_class_belonging: list = None, title: Optional[str] = None, marker_size: int = 3):
+def _2dplot_scatter_with_images(data: np.array, labels: np.array, imgs: np.array, point_class_belonging: list = None, title: Optional[str] = None, marker_size: float = 3, marker_opacity: float = 0.8):
     if not point_class_belonging:
         point_class_belonging = [['Dataset', len(labels)]]
     num_of_ds = len(point_class_belonging)
@@ -105,9 +109,9 @@ def _2dplot_scatter_with_images(data: np.array, labels: np.array, imgs: np.array
                     },
                     line={"color": "#000"},
                     reversescale=True,
-                    sizeref=4,
+                    sizeref=marker_size,
                     sizemode="diameter",
-                    opacity=0.8,
+                    opacity=marker_opacity,
                 ),
                 name=class_name,
             )
